@@ -1,9 +1,10 @@
 from .core import *
-from .relationship import (NotConnected, OUTGOING, INCOMING, EITHER, RelationshipTo,
-        RelationshipFrom, Relationship)
+from .relationship import (NotConnected, OUTGOING, INCOMING, EITHER,
+        RelationshipTo, RelationshipFrom, Relationship)
 from .cardinality import (AttemptedCardinalityViolation,
         CardinalityViolation, ZeroOrMore, OneOrMore, ZeroOrOne, One)
 from .properties import (StringProperty, IntegerProperty, AliasProperty,
-        FloatProperty, BooleanProperty, DateTimeProperty, DateProperty)
+        FloatProperty, BooleanProperty, DateTimeProperty, DateProperty,
+        JSONProperty)
 from .exception import InflateError, DeflateError, UniqueProperty
 from .signals import SIGNAL_SUPPORT
